WebPlayer class abstract

Web Player

Implementers

Constructors

WebPlayer({required MethodChannel channel})

Properties

channel → MethodChannel
final
currentPosition → num
no setter
hashCode → int
The hash code for this object.
no setterinherited
isPlaying ↔ bool
getter/setter pair
playSpeed ↔ num
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
volume ↔ num
getter/setter pair

Methods

findAssetPath(String path, String audioType, {String? package}) → String
forwardRewind(double speed) → void
loopSingleAudio(bool loop) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open({required String path, required String audioType, bool autoStart = false, double volume = 1, double? seek, double? playSpeed, Map? networkHeaders, String? package}) → Future<void>
pause() → void
play() → void
seek({double to}) → void
stop() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

methodCurrent → String
final
methodFinished → String
final
methodForwardRewindSpeed → String
final
methodIsBuffering → String
final
methodIsPlaying → String
final
methodPlaySpeed → String
final
methodPosition → String
final
methodVolume → String
final